==> jupyterlab_tensorboard_pro-0.3.1.tgz: package/lib/manager.js <==
//Tensorboard manager
import { ArrayExt, iter } from '@lumino/algorithm';
import { Signal } from '@lumino/signaling';
import { JSONExt } from '@lumino/coreutils';
import { Tensorboard } from './tensorboard';
import { ServerConnection } from '@jupyterlab/services';
import { DEFAULT_REFRESH_INTERVAL } from './consts';
/**
 * A tensorboard manager.
 */
export class TensorboardManager {
    /**
     * Construct a new tensorboard manager.
     */
    constructor(options = {}) {
        this._models = [];
        this._tensorboards = new Set();
        this._isDisposed = false;
        this._isReady = false;
        this._refreshTimer = -1;
        this._runningChanged = new Signal(this);
        this.serverSettings = options.serverSettings || ServerConnection.makeSettings();
        this._readyPromise = this._refreshRunning();
        this._refreshTimer = setInterval(() => {
            if (typeof document !== 'undefined' && document.hidden) {
                return;
            }
            this._refreshRunning();
        }, 10000);
    }
    /**
     * A signal emitted when the running tensorboards change.
     */
    get runningChanged() {
        return this._runningChanged;
    }
    /**
     * Test whether the terminal manager is disposed.
     */
    get isDisposed() {
        return this._isDisposed;
    }
    /**
     * Dispose of the resources used by the manager.
     */
    dispose() {
        if (this.isDisposed) {
            return;
        }
        this._isDisposed = true;
        clearInterval(this._refreshTimer);
        Signal.clearData(this);
        this._models = [];
    }
    /**
     * Test whether the manager is ready.
     */
    get isReady() {
        return this._isReady;
    }
    /**
     * A promise that fulfills when the manager is ready.
     */
    get ready() {
        return this._readyPromise;
    }
    /**
     * Create an iterator over the most recent running Tensorboards.
     *
     * @returns A new iterator over the running tensorboards.
     */
    running() {
        return iter(this._models);
    }
    /**
     * Create a new tensorboard.
     *
     * @param logdir - The logdir used to create a new tensorboard.
     *
     * @param options - The options used to connect to the tensorboard.
     *
     * @returns A promise that resolves with the tensorboard instance.
     */
    startNew(logdir, refreshInterval = DEFAULT_REFRESH_INTERVAL, options) {
        return Tensorboard.startNew(logdir, refreshInterval, this._getOptions(options)).then(tensorboard => {
            this._onStarted(tensorboard);
            return tensorboard;
        });
    }
    /**
     * Shut down a tensorboard by name.
     */
    shutdown(name) {
        const index = ArrayExt.findFirstIndex(this._models, value => value.name === name);
        if (index === -1) {
            return;
        }
        this._models.splice(index, 1);
        this._runningChanged.emit(this._models.slice());
        return Tensorboard.shutdown(name, this.serverSettings).then(() => {
            const toRemove = [];
            this._tensorboards.forEach(t => {
                if (t.name === name) {
                    t.dispose();
                    toRemove.push(t);
                }
            });
            toRemove.forEach(s => {
                this._tensorboards.delete(s);
            });
        });
    }
    /**
     * Shut down all tensorboards.
     *
     * @returns A promise that resolves when all of the tensorboards are shut down.
     */
    shutdownAll() {
        const models = this._models;
        if (models.length > 0) {
            this._models = [];
            this._runningChanged.emit([]);
        }
        return this._refreshRunning().then(() => {
            return Promise.all(models.map(model => {
                return Tensorboard.shutdown(model.name, this.serverSettings).then(() => {
                    const toRemove = [];
                    this._tensorboards.forEach(t => {
                        t.dispose();
                        toRemove.push(t);
                    });
                    toRemove.forEach(t => {
                        this._tensorboards.delete(t);
                    });
                });
            })).then(() => {
                return undefined;
            });
        });
    }
    /**
     * Force a refresh of the running tensorboards.
     *
     * @returns A promise that with the list of running tensorboards.
     */
    refreshRunning() {
        return this._refreshRunning();
    }
    /**
     * Handle a tensorboard terminating.
     */
    _onTerminated(name) {
        const index = ArrayExt.findFirstIndex(this._models, value => value.name === name);
        if (index !== -1) {
            this._models.splice(index, 1);
            this._runningChanged.emit(this._models.slice());
        }
    }
    /**
     * Handle a tensorboard starting.
     */
    _onStarted(tensorboard) {
        const name = tensorboard.name;
        this._tensorboards.add(tensorboard);
        const index = ArrayExt.findFirstIndex(this._models, value => value.name === name);
        if (index === -1) {
            this._models.push(tensorboard.model);
            this._runningChanged.emit(this._models.slice());
        }
        tensorboard.terminated.connect(() => {
            this._onTerminated(name);
        });
    }
    /**
     * Refresh the running tensorboards.
     */
    _refreshRunning() {
        return Tensorboard.listRunning(this.serverSettings).then(models => {
            this._isReady = true;
            if (!JSONExt.deepEqual(models, this._models)) {
                const names = models.map(r => r.name);
                const toRemove = [];
                this._tensorboards.forEach(t => {
                    if (names.indexOf(t.name) === -1) {
                        t.dispose();
                        toRemove.push(t);
                    }
                });
                toRemove.forEach(t => {
                    this._tensorboards.delete(t);
                });
                this._models = models.slice();
                this._runningChanged.emit(models);
            }
        });
    }
    /**
     * Get a set of options to pass.
     */
    _getOptions(options = {}) {
        return Object.assign(Object.assign({}, options), { serverSettings: this.serverSettings });
    }
}

==> jupyterlab_tensorboard_pro-0.7.2.tgz: package/lib/manager.js <==
//Tensorboard manager
import { ArrayExt, iter } from '@lumino/algorithm';
import { Signal } from '@lumino/signaling';
import { JSONExt } from '@lumino/coreutils';
import { Tensorboard } from './tensorboard';
import { ServerConnection } from '@jupyterlab/services';
import { DEFAULT_ENABLE_MULTI_LOG, DEFAULT_REFRESH_INTERVAL } from './consts';
/**
 * A tensorboard manager.
 */
export class TensorboardManager {
    /**
     * Construct a new tensorboard manager.
     */
    constructor(options = {}) {
        this._models = [];
        this._tensorboards = new Set();
        this._isDisposed = false;
        this._isReady = false;
        this._refreshTimer = -1;
        this._runningChanged = new Signal(this);
        this._statusConfig = null;
        this.serverSettings = options.serverSettings || ServerConnection.makeSettings();
        this._readyPromise = this._refreshRunning();
        this._refreshTimer = setInterval(() => {
            if (typeof document !== 'undefined' && document.hidden) {
                return;
            }
            this._refreshRunning();
        }, 10000);
        this.getStaticConfigPromise = this._getStaticConfig();
    }
    /**
     * A signal emitted when the running tensorboards change.
     */
    get runningChanged() {
        return this._runningChanged;
    }
    /**
     * Test whether the terminal manager is disposed.
     */
    get isDisposed() {
        return this._isDisposed;
    }
    /**
     * Dispose of the resources used by the manager.
     */
    dispose() {
        if (this.isDisposed) {
            return;
        }
        this._isDisposed = true;
        clearInterval(this._refreshTimer);
        Signal.clearData(this);
        this._models = [];
    }
    /**
     * Test whether the manager is ready.
     */
    get isReady() {
        return this._isReady;
    }
    /**
     * A promise that fulfills when the manager is ready.
     */
    get ready() {
        return this._readyPromise;
    }
    /**
     * Create an iterator over the most recent running Tensorboards.
     *
     * @returns A new iterator over the running tensorboards.
     */
    running() {
        return iter(this._models);
    }
    formatDir(dir) {
        var _a;
        const pageRoot = (_a = this._statusConfig) === null || _a === void 0 ? void 0 : _a.notebook_dir;
        if (dir.includes(',')) {
            const dirs = dir.split(',');
            return dirs
                .map(dir => {
                if (dir.includes(':')) {
                    return `${dir.split(':')[0]}:${this.formatDir(dir.split(':')[1])}`;
                }
                else {
                    return this.formatDir(dir);
                }
            })
                .join(',');
        }
        if (pageRoot && dir.indexOf(pageRoot) === 0) {
            let replaceResult = dir.replace(pageRoot, '');
            if (replaceResult === '') {
                replaceResult = '/';
            }
            const formatted = `${replaceResult}`.replace(/^\//, '');
            if (!formatted) {
                return '<workspace_root>';
            }
            return formatted;
        }
        return dir;
    }
    /**
     * Create a new tensorboard.
     *
     * @param logdir - The logdir used to create a new tensorboard.
     *
     * @param options - The options used to connect to the tensorboard.
     *
     * @returns A promise that resolves with the tensorboard instance.
     */
    startNew(logdir, refreshInterval = DEFAULT_REFRESH_INTERVAL, enableMultiLog = DEFAULT_ENABLE_MULTI_LOG, options) {
        return Tensorboard.startNew(logdir, refreshInterval, enableMultiLog, this._getOptions(options)).then(tensorboard => {
            this._onStarted(tensorboard);
            return tensorboard;
        });
    }
    /**
     * Shut down a tensorboard by name.
     */
    async shutdown(name) {
        const index = ArrayExt.findFirstIndex(this._models, value => value.name === name);
        if (index === -1) {
            return;
        }
        this._models.splice(index, 1);
        this._runningChanged.emit(this._models.slice());
        return Tensorboard.shutdown(name, this.serverSettings).then(() => {
            const toRemove = [];
            this._tensorboards.forEach(t => {
                if (t.name === name) {
                    t.dispose();
                    toRemove.push(t);
                }
            });
            toRemove.forEach(s => {
                this._tensorboards.delete(s);
            });
        });
    }
    /**
     * Shut down all tensorboards.
     *
     * @returns A promise that resolves when all of the tensorboards are shut down.
     */
    shutdownAll() {
        const models = this._models;
        if (models.length > 0) {
            this._models = [];
            this._runningChanged.emit([]);
        }
        return this._refreshRunning().then(() => {
            return Promise.all(models.map(model => {
                return Tensorboard.shutdown(model.name, this.serverSettings).then(() => {
                    const toRemove = [];
                    this._tensorboards.forEach(t => {
                        t.dispose();
                        toRemove.push(t);
                    });
                    toRemove.forEach(t => {
                        this._tensorboards.delete(t);
                    });
                });
            })).then(() => {
                return undefined;
            });
        });
    }
    /**
     * Force a refresh of the running tensorboards.
     *
     * @returns A promise that with the list of running tensorboards.
     */
    refreshRunning() {
        return this._refreshRunning();
    }
    /**
     * Handle a tensorboard terminating.
     */
    _onTerminated(name) {
        const index = ArrayExt.findFirstIndex(this._models, value => value.name === name);
        if (index !== -1) {
            this._models.splice(index, 1);
            this._runningChanged.emit(this._models.slice());
        }
    }
    /**
     * Handle a tensorboard starting.
     */
    _onStarted(tensorboard) {
        const name = tensorboard.name;
        this._tensorboards.add(tensorboard);
        const index = ArrayExt.findFirstIndex(this._models, value => value.name === name);
        if (index === -1) {
            this._models.push(tensorboard.model);
            this._runningChanged.emit(this._models.slice());
        }
        tensorboard.terminated.connect(() => {
            this._onTerminated(name);
        });
    }
    /**
     * Refresh the running tensorboards.
     */
    _refreshRunning() {
        return Tensorboard.listRunning(this.serverSettings).then(models => {
            this._isReady = true;
            if (!JSONExt.deepEqual(models, this._models)) {
                const names = models.map(r => r.name);
                const toRemove = [];
                this._tensorboards.forEach(t => {
                    if (names.indexOf(t.name) === -1) {
                        t.dispose();
                        toRemove.push(t);
                    }
                });
                toRemove.forEach(t => {
                    this._tensorboards.delete(t);
                });
                this._models = models.slice();
                this._runningChanged.emit(models);
            }
        });
    }
    _getStaticConfig() {
        return Tensorboard.getStaticConfig(this.serverSettings).then(config => {
            this._statusConfig = config;
        });
    }
    /**
     * Get a set of options to pass.
     */
    _getOptions(options = {}) {
        return Object.assign(Object.assign({}, options), { serverSettings: this.serverSettings });
    }
}
